@@ -239,7 +239,7 @@ class VectorToRaster(EOTask):
         """
         rasters = [rasterio.features.rasterize([shape], out=np.copy(out), **rasterize_args) for shape in shapes]
 
-        overlap_mask = np.zeros(out.shape, dtype=np.bool)
+        overlap_mask = np.zeros(out.shape, dtype=bool)
         no_data = self.no_data_value
 
         out[:] = rasters[0][:]
@@ -284,7 +284,7 @@ class RasterToVector(EOTask):
     """ Task for transforming raster mask feature into vector feature.
 
     Each connected component with the same value on the raster mask is turned into a shapely polygon. Polygon are
-    returned as a geometry column in a ``geopandas.GeoDataFrame``structure together with a column `VALUE` with
+    returned as a geometry column in a ``geopandas.GeoDataFrame`` structure together with a column `VALUE` with
     values of each polygon.
 
     If raster mask feature has time component, vector feature will also have a column `TIMESTAMP` with timestamps to
@@ -295,13 +295,12 @@ class RasterToVector(EOTask):
     def __init__(self, features, *, values=None, values_column='VALUE', raster_dtype=None, **rasterio_params):
         """
         :param features: One or more raster mask features which will be vectorized together with an optional new name
-        of vector feature. If no new name is given the same name will be used.
+            of vector feature. If no new name is given the same name will be used.
 
-        Examples:
-            features=(FeatureType.MASK, 'CLOUD_MASK', 'VECTOR_CLOUD_MASK')
-
-            features=[(FeatureType.MASK_TIMELESS, 'CLASSIFICATION'), (FeatureType.MASK, 'MONOTEMPORAL_CLASSIFICATION')]
+            Examples:
 
+            - `features=(FeatureType.MASK, 'CLOUD_MASK', 'VECTOR_CLOUD_MASK')`
+            - `features=[(FeatureType.MASK_TIMELESS, 'CLASSIFICATION'), (FeatureType.MASK, 'TEMPORAL_CLASSIFICATION')]`
         :type features: object supported by eolearn.core.utilities.FeatureParser class
         :param values: List of values which will be vectorized. By default is set to ``None`` and all values will be
             vectorized
@@ -342,7 +341,7 @@ class RasterToVector(EOTask):
         """
         mask = None
         if self.values:
-            mask = np.zeros(raster.shape, dtype=np.bool)
+            mask = np.zeros(raster.shape, dtype=bool)
             for value in self.values:
                 mask[raster == value] = True
 
@@ -356,11 +355,11 @@ class RasterToVector(EOTask):
                 value_list.append(value)
 
         series_dict = {
-            self.values_column: pd.Series(value_list),
+            self.values_column: pd.Series(value_list, dtype=self.raster_dtype),
             'geometry': GeoSeries(geo_list)
         }
         if timestamp is not None:
-            series_dict['TIMESTAMP'] = pd.Series([timestamp] * len(geo_list))
+            series_dict['TIMESTAMP'] = pd.to_datetime([timestamp] * len(geo_list))
 
         vector_data = GeoDataFrame(series_dict, crs=crs.pyproj_crs())
 
